==> fantacalciobazar_0.5.tar.gz: fantacalciobazar/vota_sondaggio.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {


if (@is_file("$percorso_cartella_dati/sondaggio.php")) {

include("$percorso_cartella_dati/sondaggio.php");
$voti_giocatore = "voti_".$nome_utente;
$voti_giocatore = count($$voti_giocatore);
if ($vota and ($voti_consentiti == 0 or $voti_giocatore < $voti_consentiti)) {
$lock = fopen("$percorso_cartella_dati/sondaggio.lock","w+");
flock($lock,2);
include("$percorso_cartella_dati/sondaggio.php");
$linee_sondaggio = file("$percorso_cartella_dati/sondaggio.php");
$filesondaggio = fopen("$percorso_cartella_dati/sondaggio.php","w+");
flock($filesondaggio,2);
$voti = "voti".$voto;
$$voti++;
$lung_nome_utente = strlen($nome_utente) + 6;
$num_linee_sondaggio = count($linee_sondaggio);
for ($num1 = 0 ; $num1 < $num_linee_sondaggio; $num1++) {
if (substr($linee_sondaggio[$num1],0,6) == "\$voti".$voto or substr($linee_sondaggio[$num1],0,7) == "\$voti".$voto) {
$linee_sondaggio[$num1] = "\$voti".$voto." = ".$$voti.";
";
} # fine if (substr($linee_sondaggio[$num1],0,6) == "\$voti".$voto or substr($linee_sondaggio[$num1],0,7) == "\$voti".$voto)
if ($voti_consentiti != 0 or $voto_palese == "SI") {
if (substr($linee_sondaggio[$num1],0,$lung_nome_utente) == "\$voti_".$nome_utente) {
if ($voti_giocatore != 0) $linee_sondaggio[$num1] = str_replace(");",",);",$linee_sondaggio[$num1]);
if ($voto_palese == "NO") $nuovo_voto = 0;
else $nuovo_voto = $voto;
$linee_sondaggio[$num1] = str_replace(");","\"$nuovo_voto\");",$linee_sondaggio[$num1]);
} # fine if (substr($linee_sondaggio[$num1],0,$lung_nome_utente) == "\$voti_".$nome_utente)
} # fine if ($voti_consentiti != 0 or $voto_palese == "SI")
} # fine for $num1
rewind($filesondaggio);
for ($num1 = 0 ; $num1 < $num_linee_sondaggio; $num1++) {
fwrite($filesondaggio,$linee_sondaggio[$num1]);
} # fine for $num1
flock($filesondaggio,3);
fclose($filesondaggio);
flock($lock,3);
fclose($lock);

include("$percorso_cartella_dati/sondaggio.php");
} # fine if ($vota and ($voti_consentiti == 0 or $voti_giocatore < $voti_consentiti))


echo "<b>Domanda</b>: $domanda<br>";
$num_opzioni = count($opzioni);
$voti_tot = 0;
for ($num1 = 0 ; $num1 < $num_opzioni; $num1++) {
$voti  = "voti".($num1+1);
$voti_tot = $voti_tot + $$voti;
} # fine for $num1
$voti_tot_p = $voti_tot;
if ($voti_tot_p == 0) $voti_tot_p = 1;
for ($num1 = 0 ; $num1 < $num_opzioni; $num1++) {
$voti  = "voti".($num1+1);
$voti  = $$voti;
$percentuale = round((($voti*100)/$voti_tot_p),1);
echo "<b>".($num1+1)."</b>. ".$opzioni[$num1].":<font color=\"red\"><b>$percentuale%</b></font> ($voti voti)<br>";
} # fine for $num1
echo "<br>Voti totali: $voti_tot<br><br>";

if ($voto_palese == "SI") {
$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
echo  "Voti di $giocatore : ";
$voti_giocatore = "voti_".$giocatore;
$num_voti_giocatore = count($$voti_giocatore);
$lista_voti = "";
for($num2 = 0 ; $num2 < $num_voti_giocatore; $num2++) $lista_voti .= ${$voti_giocatore}[$num2].", ";
echo substr($lista_voti,0,-2)."<br>";
next($pass);
} # fine for $num1
} # fine if ($voto_palese == "SI")

} # fine if (@is_file("$percorso_cartella_dati/sondaggio.php"))

echo "<center><form method=\"post\" action=\"./messaggi.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>

==> fantacalciobazar_0.5.2.tar.gz: fantacalciobazar/vota_sondaggio.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {


if (@is_file("$percorso_cartella_dati/sondaggio.php")) {

include("$percorso_cartella_dati/sondaggio.php");
$voti_giocatore = "voti_".$nome_utente;
$voti_giocatore = count($$voti_giocatore);
if ($vota and ($voti_consentiti == 0 or $voti_giocatore < $voti_consentiti)) {
$lock = fopen("$percorso_cartella_dati/sondaggio.lock","w+");
flock($lock,2);
include("$percorso_cartella_dati/sondaggio.php");
$linee_sondaggio = file("$percorso_cartella_dati/sondaggio.php");
$filesondaggio = fopen("$percorso_cartella_dati/sondaggio.php","w+");
flock($filesondaggio,2);
$voti = "voti".$voto;
$$voti++;
$lung_nome_utente = strlen($nome_utente) + 6;
$num_linee_sondaggio = count($linee_sondaggio);
for ($num1 = 0 ; $num1 < $num_linee_sondaggio; $num1++) {
if (substr($linee_sondaggio[$num1],0,7) == "\$voti".$voto." " or substr($linee_sondaggio[$num1],0,8) == "\$voti".$voto." ") {
$linee_sondaggio[$num1] = "\$voti".$voto." = ".$$voti.";
";
} # fine if (substr($linee_sondaggio[$num1],0,6) == "\$voti".$voto or substr($linee_sondaggio[$num1],0,7) == "\$voti".$voto)
if ($voti_consentiti != 0 or $voto_palese == "SI") {
if (substr($linee_sondaggio[$num1],0,$lung_nome_utente) == "\$voti_".$nome_utente) {
if ($voti_giocatore != 0) $linee_sondaggio[$num1] = str_replace(");",",);",$linee_sondaggio[$num1]);
if ($voto_palese == "NO") $nuovo_voto = 0;
else $nuovo_voto = $voto;
$linee_sondaggio[$num1] = str_replace(");","\"$nuovo_voto\");",$linee_sondaggio[$num1]);
} # fine if (substr($linee_sondaggio[$num1],0,$lung_nome_utente) == "\$voti_".$nome_utente)
} # fine if ($voti_consentiti != 0 or $voto_palese == "SI")
} # fine for $num1
rewind($filesondaggio);
for ($num1 = 0 ; $num1 < $num_linee_sondaggio; $num1++) {
fwrite($filesondaggio,$linee_sondaggio[$num1]);
} # fine for $num1
flock($filesondaggio,3);
fclose($filesondaggio);
flock($lock,3);
fclose($lock);

include("$percorso_cartella_dati/sondaggio.php");
} # fine if ($vota and ($voti_consentiti == 0 or $voti_giocatore < $voti_consentiti))


echo "<b>Domanda</b>: $domanda<br>";
$num_opzioni = count($opzioni);
$voti_tot = 0;
for ($num1 = 0 ; $num1 < $num_opzioni; $num1++) {
$voti  = "voti".($num1+1);
$voti_tot = $voti_tot + $$voti;
} # fine for $num1
$voti_tot_p = $voti_tot;
if ($voti_tot_p == 0) $voti_tot_p = 1;
for ($num1 = 0 ; $num1 < $num_opzioni; $num1++) {
$voti  = "voti".($num1+1);
$voti  = $$voti;
$percentuale = round((($voti*100)/$voti_tot_p),1);
echo "<b>".($num1+1)."</b>. ".$opzioni[$num1].":<font color=\"red\"><b>$percentuale%</b></font> ($voti voti)<br>";
} # fine for $num1
echo "<br>Voti totali: $voti_tot<br><br>";

if ($voto_palese == "SI") {
$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
echo  "Voti di $giocatore : ";
$voti_giocatore = "voti_".$giocatore;
$num_voti_giocatore = count($$voti_giocatore);
$lista_voti = "";
for($num2 = 0 ; $num2 < $num_voti_giocatore; $num2++) $lista_voti .= ${$voti_giocatore}[$num2].", ";
echo substr($lista_voti,0,-2)."<br>";
next($pass);
} # fine for $num1
} # fine if ($voto_palese == "SI")

} # fine if (@is_file("$percorso_cartella_dati/sondaggio.php"))

echo "<center><form method=\"post\" action=\"./messaggi.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>
